<div align="center">
  <h1>koreanbots py-sdk</h1>
    
  [![pypi](https://img.shields.io/pypi/v/koreanbots.svg)](https://pypi.org/project/koreanbots/)
  [![pypi](https://img.shields.io/pypi/pyversions/koreanbots.svg)](https://pypi.org/project/koreanbots/)
  [![license](https://img.shields.io/github/license/koreanbots/py-sdk.svg)](https://github.com/koreanbots/py-sdk/blob/master/LICENSE)
  [![downloads](https://img.shields.io/pypi/dm/koreanbots.svg)](https://pypi.org/project/koreanbots/)
  [![codecov](https://codecov.io/gh/koreanbots/py-sdk/branch/master/graph/badge.svg?token=EEZDCQRLW5)](https://codecov.io/gh/koreanbots/py-sdk)
</div>
 
> Official Python SDK for [KOREANBOTS](https://koreanbots.dev)

## 문서

[문서](https://koreanbots.readthedocs.io/en/latest/)
